Footnote references, like [5]. Note that footnotes may get rearranged, e.g., to the bottom of the “page”.

[5]

A numerical footnote. Note there’s no colon after the ].

Autonumbered footnotes are possible, like using [1] and [2].

[1]

This is the first one.

[2]

This is the second one.

They may be assigned ‘autonumber labels’ - for instance, [4] and [3].

[3]

a.k.a. third

[4]

a.k.a. fourth

Auto-symbol footnotes are also possible, like this: [*] and [†].

[*]

This is the first one.

[†]

This is the second one.